==> connectagram_1.2.10.orig.tar.gz: connectagram-1.2.10/translations/connectagram_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Łańcuch</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Ładowanie</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Wstrzymano</translation>
    </message>
</context>
<context>
    <name>Definitions</name>
    <message>
        <source>Definitions</source>
        <translation>Określenia</translation>
    </message>
    <message>
        <source>Downloading definition...</source>
        <translation>Pobieranie definicji...</translation>
    </message>
    <message>
        <source>Unsolved word</source>
        <translation>Nierozwiązane słowo</translation>
    </message>
</context>
<context>
    <name>Dictionary</name>
    <message>
        <source>Definition from Wiktionary, the free dictionary</source>
        <translation>Definicja z Wktionary, darmowego słownika</translation>
    </message>
    <message>
        <source>No definition found</source>
        <translation>Nie znaleziono żadnej definicji</translation>
    </message>
    <message>
        <source>Unable to connect to Wiktionary</source>
        <translation>Nie można połączyć się z Wiktionary</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Ogrodzenie</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Wybierz język programu:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Język systemowy&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Uwaga</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Proszę ponownie uruchomić ten program, aby zastosować zmianę języka.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nowa gra</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Niski</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Średni</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Wysoki</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Bardzo wysoki</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Język:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Długość słowa:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Ilość słów:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n litera</numerusform>
            <numerusform>%n litery</numerusform>
            <numerusform>%n liter</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Krążki</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Scores</source>
        <translation>Wyniki</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Wynik</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Czas</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Słowa</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Długość</translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Schody</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Kręta</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Fala</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Sukces</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Ładowanie</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Wstrzymano</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Określenia</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Wskazówka</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Gra</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nowa</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Wybierz...</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Szczegóły</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Wstrzymano</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Wskazówka</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>&amp;Określenia</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Wyniki</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Zakończ</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ustawienia</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Język programu...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Wybierz grę</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Numer gry:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Przepraszam</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Nie można uruchomić żądany gry.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Gra rozszyfrowania słów</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Prawo autorskie &amp;copy; 2009-%1 przez Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Wydano na licencji &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Definicje są z &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Szczegóły</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Wzór:</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>Wznowienie</translation>
    </message>
</context>
</TS>

==> connectagram_1.3.5.orig.tar.gz: connectagram-1.3.5/translations/connectagram_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Łańcuch</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Ładowanie</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Wstrzymano</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Ogrodzenie</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Wybierz język programu:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Język systemowy&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Uwaga</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Proszę ponownie uruchomić ten program, aby zastosować zmianę języka.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nowa gra</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Niski</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Średni</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Wysoki</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Bardzo wysoki</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Język:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Długość słowa:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Ilość słów:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n litera</numerusform>
            <numerusform>%n litery</numerusform>
            <numerusform>%n liter</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Krążki</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Najlepsze wyniki</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation>Stopień</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Imię</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Wynik</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Czas</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Słowa</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Długość</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Gratulacje!</translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation>Pobiłeś twój najlepszy wynik!</translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation>Dobra robota!</translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation>Masz nowy najlepszy wynik!</translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Schody</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Kręta</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Fala</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Sukces</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Ładowanie</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Wstrzymano</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Określenia</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Wskazówka</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Gra</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nowa</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Wybierz...</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Szczegóły</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Wstrzymano</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Wskazówka</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>&amp;Określenia</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>Najlepsze &amp;wyniki</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Zakończ</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ustawienia</translation>
    </message>
    <message>
        <source>&amp;Dark Mode</source>
        <translation>Tryb &amp;ciemny</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Język programu...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Wybierz grę</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Numer gry:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Przepraszam</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Nie można uruchomić żądany gry.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Gra rozszyfrowania słów</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Prawo autorskie &amp;copy; 2009-%1 przez Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Wydano na licencji &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Definicje są z &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Szczegóły</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Wzór:</translation>
    </message>
</context>
</TS>
